@@ -1,4 +1,4 @@
-from jaaql.utilities.utils import load_config, await_jaaql_installation, get_base_url, await_jaaql_bootup
+from jaaql.utilities.utils import load_config, await_ems_startup, get_base_url, await_jaaql_bootup
 from jaaql.constants import HEADER__security_bypass, VAULT_KEY__jaaql_local_access_key, ENDPOINT__install
 from jaaql.utilities.vault import Vault, DIR__vault
 import os
@@ -10,38 +10,22 @@ import time
 
 DIR__install_scripts = "install_scripts"
 
-SUBMIT_METHOD = "POST"
-SUBMIT_ENDPOINT = "/submit"
-
 
 def process_script(script: str, base_url: str, bypass_header: dict):
     script = script.replace("\r\n", "\n")
     commands = script.split("\n\n")
     if len(commands[0]) == 0:
         print("Script is empty")
-
-    cur_submits = []
-
     for command in commands:
-        try:
-            action = command.split("\n")[0].strip()
-            method = action.split(" ")[0].strip()
-            endpoint = action.split(" ")[1].strip()
+        action = command.split("\n")[0].strip()
+        method = action.split(" ")[0]
+        endpoint = action.split(" ")[1]
 
-            loaded_json = None
-            if len(command.split("\n")) > 1:
-                loaded_json = json.loads("\n".join(command.split("\n")[1:]).strip())
-        except ValueError:
-            print("command {0} is unprocessable - skipping script {1}".format(command, script))
-            return
-        else:
-            if method == SUBMIT_METHOD and endpoint == SUBMIT_ENDPOINT:
-                cur_submits.append(loaded_json)
-            else:
-                requests.request(method, base_url + endpoint, headers=bypass_header, json=loaded_json)
+        loaded_json = None
+        if len(command.split("\n")) > 1:
+            loaded_json = json.loads("\n".join(command.split("\n")[1:]).strip())
 
-    if len(cur_submits) != 0:
-        requests.request(SUBMIT_METHOD, base_url + SUBMIT_ENDPOINT, headers=bypass_header, json=cur_submits)
+        requests.request(method, base_url + endpoint, headers=bypass_header, json=loaded_json)
 
 
 def bootup(vault_key, is_gunicorn: bool = False, install_on_bootup: bool = False):
@@ -63,11 +47,11 @@ def bootup(vault_key, is_gunicorn: bool = False, install_on_bootup: bool = False
             "superjaaql_password": "passw0rd",
             "allow_uninstall": False
         }
-        if not is_gunicorn or os.environ.get("DB_CONNECTION_STRING"):
-            json_data["db_connection_string"] = os.environ.get("DB_CONNECTION_STRING", "postgresql://postgres:123456@localhost:5432/jaaql")
+        if not is_gunicorn:
+            json_data["db_connection_string"] = "postgresql://postgres:123456@localhost:5432/jaaql"
         requests.post(base_url + ENDPOINT__install, json=json_data)
 
-    await_jaaql_installation(config, is_gunicorn)
+    await_ems_startup()
     vault = Vault(vault_key, DIR__vault)
 
     bypass_header = {HEADER__security_bypass: vault.get_obj(VAULT_KEY__jaaql_local_access_key)}
@@ -88,7 +72,7 @@ def bootup(vault_key, is_gunicorn: bool = False, install_on_bootup: bool = False
                 if i != 0:
                     print()
 
-                with open(join(script_root, script), "r", encoding="utf-8") as script_file:
+                with open(join(script_root, script), "r") as script_file:
                     print("Processing script " + script)
                     process_script(script_file.read(), base_url, bypass_header)
                 i += 1
